@@ -38,7 +38,7 @@ def pull(toolVersionId):
     template['id'] = toolEntity['id']
     auth = common.get(url=common.get_cloud_base_url() + '/tool/pass')
     client = docker.from_env()
-    print("pull in, please wait")
+    print("pulling, please wait")
     client.images.pull(repository=common.get_docker_registry() + '/' + pullToolEntity['path'],
                        tag="latest",
                        auth_config={'username': auth['account'], 'password': auth['password']})
