@@ -48,9 +48,11 @@ def pushImage(config_json):
                 print(line['error'])
                 client.images.remove(common.get_docker_registry() + '/' + path + ':latest')
                 myLogger.error_logger('Tool upload failed')
-            if 'progressDetail' in line and (line['progressDetail'] != '' and line['progressDetail'] != {}):
+            if 'progressDetail' in line and (line['progressDetail'] != '' and line['progressDetail'] != {} and 'current' in line['progressDetail'] and 'total' in line['progressDetail']):
                 current = line['progressDetail']['current']
                 total = line['progressDetail']['total']
+                if current > total:
+                    current = total
                 progress_num = (current / total)*100
                 progress = round(progress_num, 2)
                 print('uploading: '+str(progress)+"%")
